/**
 * @(#)FiscnProperties.java
 * Copyright PFU LIMITED 2009-2014
 * 
 */
package com.fujitsu.pfu.fiscn.sdksample;

import com.fujitsu.pfu.fiscn.sdk.FiscnConstant;

/**
 * Definition class for FiscnProperties<BR>
 * This is a data class.
 * <BR>
 */
public class FiscnProperties {
	
	/**
	 * automatic border detection
	 */
	private boolean autoBorderDetection = false;
	
	/**
	 * automatic image area separation
	 */
	private int autoSeparation = FiscnConstant.AUTOSEPARATION_OFF;
	
	/**
	 * background tracking
	 */
	private int background = FiscnConstant.BACKGROUND_OFF;
	
	/**
	 * setting the background color (black or white background)
	 */
	private int backgroundColor = FiscnConstant.BACKGROUNDCOLOR_OFF;
	
	/**
	 * duplex binding direction
	 */
	private int binding = FiscnConstant.BINDING_SIDE;
	
	/**
	 * brightness
	 */
	private int brightness = 128 ;
	
	/**
	 * exit setting for the user interface (UI) of the source
	 */
	private boolean closeSourceUI = false;
	
	/**
	 * data compression type
	 */
	private int compressionType = FiscnConstant.COMPRESSIONTYPE_MMR;
	
	/**
	 * contrast
	 */
	private int contrast = 128;
	
	/**
	 * custom gamma
	 */
	private float customGamma = 2.2f;
	
	/**
	 * custom document length
	 */
	private float customPaperLength = 1;
	
	/**
	 * custom document width
	 */
	private float customPaperWidth = 1;
	
	/**
	 * custom resolution
	 */
	private int customResolution = 300;
	
	/**
	 * endorser/imprinter setting
	 */
	private boolean endorser = false;
	
	/**
	 * endorser/imprinter counter step direction setting
	 */
	private int endorserCountDirection = FiscnConstant.ENDORSERCOUNTDIRECTION_ADD;
	
	/**
	 * endorser/imprinter counter default setting
	 */
	private long endorserCounter = 0;
	
	/**
	 * endorser/imprinter counter step count setting
	 */
	private int endorserCountStep = FiscnConstant.ENDORSERCOUNTSTEP_1STEP;
	
	/**
	 * endorser/imprinter print direction setting
	 */
	private int endorserDirection = FiscnConstant.ENDORSERDIRECTION_TOUNDER;
	
	/**
	 * endorser/imprinter start print position setting
	 */
	private float endorserOffset = 0;
	
	/**
	 * endorser/imprinter string setting 
	 */
	private String endorserString = "";
	
	/**
	 * file serial number setting
	 */
	private long fileCounter = 1;
	
	/**
	 * file name 
	 */
	private String fileName = "";
	
	/**
	 *  file format (image data format)
	 */
	private int fileType = FiscnConstant.FILETYPE_TIFF;
	
	/**
	 * dropout color 
	 */
	private int filter = FiscnConstant.FILTER_GREEN;
	
	/**
	 * gamma adjustment 
	 */
	private int gamma = FiscnConstant.GAMMA_NONE;
	
	/**
	 * gamma pattern file name
	 */
	private String gammaFile = "";
	
	/**
	 * halftone 
	 */
	private int halftone = FiscnConstant.HALFTONE_NONE;
	
	/**
	 * halftone pattern file
	 */
	private String halftoneFile = "";
	
	/**
	 * Highlight
	 */
	private int highlight = 230;
	
	/**
	 * progress indicator Display
	 */
	private boolean indicator = true;
	
	/**
	 * job control setting
	 */
	private int jobControl = FiscnConstant.JOBCONTROL_NONE;
	
	/**
	 * Jpeg data compression level
	 */
	private int jpegQuality = FiscnConstant.JPEGQUARITY_LEVEL4;
	
	/**
	 * Long document (long page) scan setting
	 */
	private boolean longPage = false;
	
	/**
	 * mirror image (flip horizontal)
	 */
	private boolean mirroring = false;
	
	/**
	 * multifeed detection
	 */
	private int multiFeed = FiscnConstant.MULTIFEED_NONE;
	
	/**
	 * dust removal mode
	 */
	private int noiseRemoval = FiscnConstant.NOISEREMOVAL_NONE;
	
	/**
	 * document orientation setting
	 */
	private int orientation = FiscnConstant.ORIENTATION_PORTRAIT;
	
	/**
	 * outline correction
	 */
	private int outline = FiscnConstant.OUTLINE_NONE;
	
	/**
	 * overscan setting
	 */
	private int overScan = FiscnConstant.OVERSCAN_OFF;

	/**
	 * file overwrite setting
	 */
	private int overwrite = FiscnConstant.OVERWRITE_CONFIRM_MODE0;
	
	/**
	 * document size
	 */
	private int paperSize = FiscnConstant.PAPERSIZE_A4;
	
	/**
	 * paper feed method
	 */
	private int paperSupply = FiscnConstant.PAPERSUPPLY_ADF;
	
	/**
	 * pixel type
	 */
	private int pixelType = FiscnConstant.PIXELTYPE_BLACKWHITE;
	
	/**
	 * ballpoint pen filtering
	 */
	private boolean preFiltering = false;
	
	/**
	 * Left Edge of the Scanning Area
	 */
	private float regionLeft = 0;
	
	/**
	 * Length of the Scanning Area
	 */
	private float regionLength = 0;
	
	/**
	 * Top Edge of the Scanning Area
	 */
	private float regionTop = 0;
	
	/**
	 * Width of the Scanning Area
	 */
	private float regionWidth = 0;
	
	/**
	 * Report Output
	 */
	private int report = FiscnConstant.REPORT_OFF;
	
	/**
	 * Report File Name
	 */
	private String reportFile = "";
	
	/**
	 * Standard Resolution
	 */
	private int resolution = FiscnConstant.RESOLUTION_300;
	
	/**
	 * Black and White Inversion
	 */
	private boolean reverse = false;
	
	/**
	 * Rotation Angle
	 */
	private int rotation = FiscnConstant.ROTATION_NONE;
	
	/**
	 * Number of Pages to be Scanned
	 */
	private int scanCount = -1;
	
	/**
	 * Output Method of Scanned Data
	 */
	private int scanTo = FiscnConstant.SCANTO_FILE;
	
	/**
	 * Selectable Edge Enhancement
	 */
	private int sEE = FiscnConstant.SEE_OFF;
	
	/**
	 * shadow
	 */
	private int shadow = 10;
	
	/**
	 * Source User Interface (UI) Display
	 */
	private boolean showSourceUI = true;
	
	/**
	 * Silent Mode
	 */
	private boolean silentMode = false;
	
	/**
	 * Skip Black Pages
	 */
	private int skipBlackPage = 0;
	
	/**
	 * Skip White Pages
	 */
	private int skipWhitePage = 0;
	
	/**
	 * OCR Smoothing Mode / Background Removal
	 */
	private boolean smoothing = false;
	
	/**
	 * Scan with the Source Current Value
	 */
	private boolean sourceCurrentScan = false;
	
	/**
	 * Threshold
	 */
	private int threshold = 128;
	
	/**
	 * Density Curve in Automatic Binarization
	 */
	private int thresholdCurve = FiscnConstant.THRESHHOLDCURVE_CURVE1;
	
	/**
	 * Data Source
	 */
	private String twainDS = "";
	
	/**
	 * Scanning an Undefined Length (Paper End Detection)
	 */
	private boolean undefinedScanning = false;
	
	/**
	 * Unit(Inch/Centimeter/Pixel)
	 */
	private int unit = FiscnConstant.UNIT_INCH;
	
	/**
	 * Automatic slice binary sensitivity setting
	 */
	private int dTCSensitivity = 50;
	
	/**
	 * Automatic slice binary character thickness setting
	 */
	private int characterThickness = 5;
	
	/**
	 * Automatic slice binary fading compensation
	 */
	private int fadingCompensation = 0;
	
	/**
	 * Automatic slice binary noise removal
	 */
	private int noiseRejection = 0;
	
	/**
	 * Automatic slice binary pattern removal setting
	 */
	private int patternRemoval = 1;
	
	/**
	 * Punch hole removal
	 */
	private int punchHoleRemoval = 0;
	
	/**
	 * Sharpness
	 */
	private int sharpness = 0;
	
	/**
	 * Automatic adjustment of brightness-related image quality
	 */
	private boolean autoBright = false;
	
	/**
	 * Background color smoothing
	 */
	private int backgroundSmoothing = 0;
	
	/**
	 * ADF/FB automatic switching
	 */
	private boolean automaticSenseMedium = false;
	
	/**
	 * Background color threshold
	 */
	private int backgroundThreshold = 50;
	
	/**
	 * Automatic (simple) binary dispersion value
	 */
	private int sDTCSensitivity = 2;
	
	/**
	 * Automatic (advanced) binary threshold
	 */
	private int aDTCThreshold = 83;
	
	/**
	 * sRGB output
	 */
	private boolean sRGB = false;
	
	/**
	 * Endorser/Imprinter print font setting
	 */
	private int endorserFont = 0;
	
	/**
	 * Barcode detection
	 */
	private boolean barcodeDetection = false;
	
	/**
	 * Barcode detection direction setting
	 */
	private int barcodeDirection = 2;
	
	/**
	 * Barcode detection area left edge position
	 */
	private float barcodeRegionLeft = 0;
	
	/**
	 * Barcode detection area length
	 */
	private float barcodeRegionLength = 0;
	
	/**
	 * Barcode detection area top edge position
	 */
	private float barcodeRegionTop = 0;
	
	/**
	 * Barcode detection area width
	 */
	private float barcodeRegionWidth = 0;
	
	/**
	 * Barcode type setting
	 */
	private long barcodeType = 511;
	
	/**
	 * Patch code detection
	 */
	private boolean patchCodeDetection = false;
	
	/**
	 * Patch code detection direction setting
	 */
	private int patchCodeDirection = 1;
	
	/**
	 * Patch code type setting
	 */
	private long patchCodeType = 303;
	
	/**
	 * Edge filler
	 */
	private int edgeFiller = 0;
	
	/**
	 * Edge filler bottom edge area setting
	 */
	private float edgeFillerBottom = 0;
	
	/**
	 * Edge filler left edge area setting
	 */
	private float edgeFillerLeft = 0;
	
	/**
	 * Edge filler right edge area setting
	 */
	private float edgeFillerRight = 0;
	
	/**
	 * Edge filler top edge area setting
	 */
	private float edgeFillerTop = 0;
	
	/**
	 * Edge filler repair
	 */
	private boolean edgeRepair = false;
	
	/**
	 * Job control type setting
	 */
	private int jobControlMode = 0;
	
	/**
	 * Blank page skip
	 */
	private int blankPageSkip = 0;
	
	/**
	 * Scan mode
	 */
	private int scanMode = 0;	
	
	/**
	 * Barcode maximum detection count setting
	 */
	private int barcodeMaxSearchPriorities = 1;
	
	/**
	 * Digital endorser setting
	 */
	private boolean digitalEndorser = false;
	
	/**
	 * Digital endorser counter step direction setting
	 */
	private int digitalEndorserCountDirection = FiscnConstant.DIGITALENDORSERCOUNTDIRECTION_ADD;
	
	/**
	 * Digital endorser counter default value setting
	 */
	private long digitalEndorserCounter = 0;
	
	/**
	 * Digital endorser counter step value setting
	 */
	private int digitalEndorserCountStep = FiscnConstant.DIGITALENDORSERCOUNTSTEP_1STEP;
	
	/**
	 * Digital endorser character string setting
	 */
	private String digitalEndorserString = "";
	
	/**
	 * Digital endorser print start position (X offset) setting
	 */
	private float digitalEndorserXOffset = 0;
	
	/**
	 * Digital endorser print start position (Y offset) setting
	 */
	private float digitalEndorserYOffset = 0;
	
	/**
	 * Chromatic dropout color sensitivity setting
	 */
	private int filterSaturationSensitivity = 50;
	
	/**
	 * Endorser/imprinter and digital endorser synchronization function setting
	 */
	private boolean synchronizationDigitalEndorser = false;
	
	/**
	 * Vertical line reduction setting
	 */
	private boolean verticalLineReduction = false;

	/**
	 * Automatic Image Quality Checker setting
	 */
	private boolean aIQCNotice = false;

	/**
	 * Background color smoothness
	 */
	private int backgroundSmoothness = 5;

	/**
	 * Priority setting during automatic paper size detection
	 */
	private int cropPriority = 0;

	/**
	 * Skew correction
	 */
	private int deskew = 1;

	/**
	 * Sizes of cropping margins
	 */
	private float cropMarginSize = 0;

	/**
	 * Specifying the paper length to disable multifeed detection
	 */
	private float multiFeedModeChangeSize = 0;

	/**
	 * Blank page output setting
	 */
	private int blankPageNotice = 0;

	/**
	 * The non-compression TRANSFER mode in hardware setting
	 */
	private boolean hwCompression = false;
	
	/**
	 * The continuance reading
	 */
	private boolean scanContinue = false;

	/**
	 * The automatic color detection sensitivity
	 */
	private int automaticColorSensitivity = 0;

	
	/**
	 * Background color used for skew correction
	 */
	private int deskewBackground = 1;
	
	/**
	 * Digital endorser print direction setting
	 */
	private int digitalEndorserDirection = 0;
	
	/**
	 * Simultaneous setting of paper end detection/background color/overscan
	 */
	private int lengthDetection = 0;

	/**
	 * Setting of multi feed notification function
	 */
	private boolean multiFeedNotice = false;

	/**
	 * Blank page skip mode setting
	 */
	private int blankPageSkipMode = 0;

	public boolean getAutoBorderDetection() {
		return this.autoBorderDetection;
	}

	public void setAutoBorderDetection(boolean autoBorderDetection) {
		this.autoBorderDetection = autoBorderDetection;
	}

	public int getAutoSeparation() {
		return this.autoSeparation;
	}

	public void setAutoSeparation(int autoSeparation) {
		this.autoSeparation = autoSeparation;
	}

	public int getBackground() {
		return this.background;
	}

	public void setBackground(int background) {
		this.background = background;
	}

	public int getBackgroundColor() {
		return this.backgroundColor;
	}

	public void setBackgroundColor(int backgroundColor) {
		this.backgroundColor = backgroundColor;
	}

	public int getBinding() {
		return this.binding;
	}

	public void setBinding(int binding) {
		this.binding = binding;
	}

	public int getBrightness() {
		return this.brightness;
	}

	public void setBrightness(int brightness) {
		this.brightness = brightness;
	}

	public boolean getCloseSourceUI() {
		return this.closeSourceUI;
	}

	public void setCloseSourceUI(boolean closeSourceUI) {
		this.closeSourceUI = closeSourceUI;
	}

	public int getCompressionType() {
		return this.compressionType;
	}

	public void setCompressionType(int compressionType) {
		this.compressionType = compressionType;
	}

	public int getContrast() {
		return this.contrast;
	}

	public void setContrast(int contrast) {
		this.contrast = contrast;
	}

	public float getCustomGamma() {
		return this.customGamma;
	}

	public void setCustomGamma(float customGamma) {
		this.customGamma = customGamma;
	}

	public float getCustomPaperLength() {
		return this.customPaperLength;
	}

	public void setCustomPaperLength(float customPaperLength) {
		this.customPaperLength = customPaperLength;
	}

	public float getCustomPaperWidth() {
		return this.customPaperWidth;
	}

	public void setCustomPaperWidth(float customPaperWidth) {
		this.customPaperWidth = customPaperWidth;
	}

	public int getCustomResolution() {
		return this.customResolution;
	}

	public void setCustomResolution(int customResolution) {
		this.customResolution = customResolution;
	}

	public boolean getEndorser() {
		return this.endorser;
	}

	public void setEndorser(boolean endorser) {
		this.endorser = endorser;
	}

	public int getEndorserCountDirection() {
		return this.endorserCountDirection;
	}

	public void setEndorserCountDirection(int endorserCountDirection) {
		this.endorserCountDirection = endorserCountDirection;
	}

	public long getEndorserCounter() {
		return this.endorserCounter;
	}

	public void setEndorserCounter(long endorserCounter) {
		this.endorserCounter = endorserCounter;
	}

	public int getEndorserCountStep() {
		return this.endorserCountStep;
	}

	public void setEndorserCountStep(int endorserCountStep) {
		this.endorserCountStep = endorserCountStep;
	}

	public int getEndorserDirection() {
		return this.endorserDirection;
	}

	public void setEndorserDirection(int endorserDirection) {
		this.endorserDirection = endorserDirection;
	}

	public float getEndorserOffset() {
		return this.endorserOffset;
	}

	public void setEndorserOffset(float endorserOffset) {
		this.endorserOffset = endorserOffset;
	}

	public String getEndorserString() {
		return this.endorserString;
	}

	public void setEndorserString(String endorserString) {
		this.endorserString = endorserString;
	}

	public long getFileCounter() {
		return this.fileCounter;
	}

	public void setFileCounter(long fileCounter) {
		this.fileCounter = fileCounter;
	}

	public String getFileName() {
		return  this.fileName;
	}

	public void setFileName(String fileName) {
		this.fileName = fileName;
	}

	public int getFileType() {
		return this.fileType;
	}

	public void setFileType(int fileType) {
		this.fileType = fileType;
	}

	public int getFilter() {
		return this.filter;
	}

	public void setFilter(int filter) {
		this.filter = filter;
	}

	public int getGamma() {
		return this.gamma;
	}

	public void setGamma(int gamma) {
		this.gamma = gamma;
	}

	public String getGammaFile() {
		return this.gammaFile;
	}

	public void setGammaFile(String gammaFile) {
		this.gammaFile = gammaFile;
	}

	public int getHalftone() {
		return this.halftone;
	}

	public void setHalftone(int halftone) {
		this.halftone = halftone;
	}

	public String getHalftoneFile() {
		return this.halftoneFile;
	}

	public void setHalftoneFile(String halftoneFile) {
		this.halftoneFile = halftoneFile;
	}

	public int getHighlight() {
		return this.highlight;
	}

	public void setHighlight(int highlight) {
		this.highlight = highlight;
	}

	public boolean getIndicator() {
		return this.indicator;
	}

	public void setIndicator(boolean indicator) {
		this.indicator = indicator;
	}

	public int getJobControl() {
		return this.jobControl;
	}

	public void setJobControl(int jobControl) {
		this.jobControl = jobControl;
	}

	public int getJpegQuality() {
		return this.jpegQuality;
	}

	public void setJpegQuality(int jpegQuality) {
		this.jpegQuality = jpegQuality;
	}

	public boolean getLongPage() {
		return this.longPage;
	}

	public void setLongPage(boolean longPage) {
		this.longPage = longPage;
	}

	public boolean getMirroring() {
		return this.mirroring;
	}

	public void setMirroring(boolean mirroring) {
		this.mirroring = mirroring;
	}

	public int getMultiFeed() {
		return this.multiFeed;
	}

	public void setMultiFeed(int multiFeed) {
		this.multiFeed = multiFeed;
	}

	public int getNoiseRemoval() {
		return this.noiseRemoval;
	}

	public void setNoiseRemoval(int noiseRemoval) {
		this.noiseRemoval = noiseRemoval;
	}

	public int getOrientation() {
		return this.orientation;
	}

	public void setOrientation(int orientation) {
		this.orientation = orientation;
	}

	public int getOutline() {
		return this.outline;
	}

	public void setOutline(int outline) {
		this.outline = outline;
	}

	public int getOverScan() {
		return this.overScan;
	}

	public void setOverScan(int overScan) {
		this.overScan = overScan;
	}

	public int getOverwrite() {
		return this.overwrite;
	}

	public void setOverwrite(int overwrite) {
		this.overwrite = overwrite;
	}
	
	public int getPaperSize() {
		return this.paperSize;
	}
	
	public void setPaperSize(int paperSize) {
		this.paperSize = paperSize;
	}
	
	public int getPaperSupply() {
		return this.paperSupply;
	}
	
	public void setPaperSupply(int paperSupply) {
		this.paperSupply = paperSupply;
	}
	
	public int getPixelType() {
		return this.pixelType;
	}
	
	public void setPixelType(int pixelType) {
		this.pixelType = pixelType;
	}
	
	public boolean getPreFiltering() {
		return this.preFiltering;
	}
	
	public void setPreFiltering(boolean preFiltering) {
		this.preFiltering = preFiltering;
	}
	
	public float getRegionLeft() {
		return this.regionLeft;
	}
	
	public void setRegionLeft(float regionLeft) {
		this.regionLeft = regionLeft;
	}
	
	public float getRegionLength() {
		return this.regionLength;
	}
	
	public void setRegionLength(float regionLength) {
		this.regionLength = regionLength;
	}
	
	public float getRegionTop() {
		return this.regionTop;
	}
	
	public void setRegionTop(float regionTop) {
		this.regionTop = regionTop;
	}
	
	public float getRegionWidth() {
		return this.regionWidth;
	}
	
	public void setRegionWidth(float regionWidth) {
		this.regionWidth = regionWidth;
	}
	
	public int getReport() {
		return this.report;
	}
	
	public void setReport(int report) {
		this.report = report;
	}
	
	public String getReportFile() {
		return this.reportFile;
	}
	
	public void setReportFile(String reportFile) {
		this.reportFile = reportFile;
	}
	
	public int getResolution() {
		return this.resolution;
	}
	
	public void setResolution(int resolution) {
		this.resolution = resolution;
	}
	
	public boolean getReverse() {
		return this.reverse;
	}
	
	public void setReverse(boolean reverse) {
		this.reverse = reverse;
	}
	
	public int getRotation() {
		return this.rotation;
	}
	
	public void setRotation(int rotation) {
		this.rotation = rotation;
	}
	
	public int getScanCount() {
		return this.scanCount;
	}
	
	public void setScanCount(int scanCount) {
		this.scanCount = scanCount;
	}
	
	public int getScanTo() {
		return this.scanTo;
	}
	
	public void setScanTo(int scanTo) {
		this.scanTo = scanTo;
	}
	
	public int getSEE() {
		return this.sEE;
	}
	
	public void setSEE(int see) {
		this.sEE = see;
	}
	
	public int getShadow() {
		return this.shadow;
	}
	
	public void setShadow(int shadow) {
		this.shadow = shadow;
	}
	
	public boolean getShowSourceUI() {
		return this.showSourceUI;
	}
	
	public void setShowSourceUI(boolean showSourceUI) {
		this.showSourceUI = showSourceUI;
	}
	
	public boolean getSilentMode() {
		return this.silentMode;
	}
	
	public void setSilentMode(boolean silentMode) {
		this.silentMode = silentMode;
	}
	
	public int getSkipBlackPage() {
		return this.skipBlackPage;
	}
	
	public void setSkipBlackPage(int skipBlackPage) {
		this.skipBlackPage = skipBlackPage;
	}
	
	public int getSkipWhitePage() {
		return this.skipWhitePage;
	}
	
	public void setSkipWhitePage(int skipWhitePage) {
		this.skipWhitePage = skipWhitePage;
	}
	
	public boolean getSmoothing() {
		return this.smoothing;
	}
	
	public void setSmoothing(boolean smoothing) {
		this.smoothing = smoothing;
	}
	
	public boolean getSourceCurrentScan() {
		return this.sourceCurrentScan;
	}
	
	public void setSourceCurrentScan(boolean sourceCurrentScan) {
		this.sourceCurrentScan = sourceCurrentScan;
	}
	
	public int getThreshold() {
		return this.threshold;
	}
	
	public void setThreshold(int threshold) {
		this.threshold = threshold;
	}
	
	public int getThresholdCurve() {
		return this.thresholdCurve;
	}
	
	public void setThresholdCurve(int thresholdCurve) {
		this.thresholdCurve = thresholdCurve;
	}
	
	public String getTwainDS() {
		return this.twainDS;
	}
	
	public void setTwainDS(String twainDS) {
		this.twainDS = twainDS;
	}
	
	public boolean getUndefinedScanning() {
		return this.undefinedScanning;
	}
	
	public void setUndefinedScanning(boolean undefinedScanning) {
		this.undefinedScanning = undefinedScanning;
	}

	public int getUnit() {
		return this.unit;
	}
	
	public void setUnit(int unit) {
		this.unit = unit;
	}
	
	public int getDTCSensitivity() {
		return dTCSensitivity;
	}

	public void setDTCSensitivity(int dTCSensitivity) {
		this.dTCSensitivity = dTCSensitivity;
	}

	public int getCharacterThickness() {
		return characterThickness;
	}

	public void setCharacterThickness(int characterThickness) {
		this.characterThickness = characterThickness;
	}

	public int getFadingCompensation() {
		return fadingCompensation;
	}

	public void setFadingCompensation(int fadingCompensation) {
		this.fadingCompensation = fadingCompensation;
	}

	public int getNoiseRejection() {
		return noiseRejection;
	}

	public void setNoiseRejection(int noiseRejection) {
		this.noiseRejection = noiseRejection;
	}

	public int getPatternRemoval() {
		return patternRemoval;
	}

	public void setPatternRemoval(int patternRemoval) {
		this.patternRemoval = patternRemoval;
	}

	public int getPunchHoleRemoval() {
		return punchHoleRemoval;
	}

	public void setPunchHoleRemoval(int punchHoleRemoval) {
		this.punchHoleRemoval = punchHoleRemoval;
	}

	public int getSharpness() {
		return sharpness;
	}

	public void setSharpness(int sharpness) {
		this.sharpness = sharpness;
	}

	public boolean getAutoBright() {
		return autoBright;
	}

	public void setAutoBright(boolean autoBright) {
		this.autoBright = autoBright;
	}

	public int getBackgroundSmoothing() {
		return backgroundSmoothing;
	}

	public void setBackgroundSmoothing(int backgroundSmoothing) {
		this.backgroundSmoothing = backgroundSmoothing;
	}

	public boolean getAutomaticSenseMedium() {
		return automaticSenseMedium;
	}

	public void setAutomaticSenseMedium(boolean automaticSenseMedium) {
		this.automaticSenseMedium = automaticSenseMedium;
	}

	public int getBackgroundThreshold() {
		return backgroundThreshold;
	}

	public void setBackgroundThreshold(int backgroundThreshold) {
		this.backgroundThreshold = backgroundThreshold;
	}

	public int getSDTCSensitivity() {
		return sDTCSensitivity;
	}

	public void setSDTCSensitivity(int sDTCSensitivity) {
		this.sDTCSensitivity = sDTCSensitivity;
	}

	public int getADTCThreshold() {
		return aDTCThreshold;
	}

	public void setADTCThreshold(int aDTCThreshold) {
		this.aDTCThreshold = aDTCThreshold;
	}

	public boolean getSRGB() {
		return sRGB;
	}

	public void setSRGB(boolean sRGB) {
		this.sRGB = sRGB;
	}

	public int getEndorserFont() {
		return endorserFont;
	}

	public void setEndorserFont(int endorserFont) {
		this.endorserFont = endorserFont;
	}

	public boolean getBarcodeDetection() {
		return barcodeDetection;
	}

	public void setBarcodeDetection(boolean barcodeDetection) {
		this.barcodeDetection = barcodeDetection;
	}

	public int getBarcodeDirection() {
		return barcodeDirection;
	}

	public void setBarcodeDirection(int barcodeDirection) {
		this.barcodeDirection = barcodeDirection;
	}

	public float getBarcodeRegionLeft() {
		return barcodeRegionLeft;
	}

	public void setBarcodeRegionLeft(float barcodeRegionLeft) {
		this.barcodeRegionLeft = barcodeRegionLeft;
	}

	public float getBarcodeRegionLength() {
		return barcodeRegionLength;
	}

	public void setBarcodeRegionLength(float barcodeRegionLength) {
		this.barcodeRegionLength = barcodeRegionLength;
	}

	public float getBarcodeRegionTop() {
		return barcodeRegionTop;
	}

	public void setBarcodeRegionTop(float barcodeRegionTop) {
		this.barcodeRegionTop = barcodeRegionTop;
	}

	public float getBarcodeRegionWidth() {
		return barcodeRegionWidth;
	}

	public void setBarcodeRegionWidth(float barcodeRegionWidth) {
		this.barcodeRegionWidth = barcodeRegionWidth;
	}

	public long getBarcodeType() {
		return barcodeType;
	}

	public void setBarcodeType(long barcodeType) {
		this.barcodeType = barcodeType;
	}

	public boolean getPatchCodeDetection() {
		return patchCodeDetection;
	}

	public void setPatchCodeDetection(boolean patchCodeDetection) {
		this.patchCodeDetection = patchCodeDetection;
	}

	public int getPatchCodeDirection() {
		return patchCodeDirection;
	}

	public void setPatchCodeDirection(int patchCodeDirection) {
		this.patchCodeDirection = patchCodeDirection;
	}

	public long getPatchCodeType() {
		return patchCodeType;
	}

	public void setPatchCodeType(long patchCodeType) {
		this.patchCodeType = patchCodeType;
	}

	public int getEdgeFiller() {
		return edgeFiller;
	}

	public void setEdgeFiller(int edgeFiller) {
		this.edgeFiller = edgeFiller;
	}

	public float getEdgeFillerBottom() {
		return edgeFillerBottom;
	}

	public void setEdgeFillerBottom(float edgeFillerBottom) {
		this.edgeFillerBottom = edgeFillerBottom;
	}

	public float getEdgeFillerLeft() {
		return edgeFillerLeft;
	}

	public void setEdgeFillerLeft(float edgeFillerLeft) {
		this.edgeFillerLeft = edgeFillerLeft;
	}

	public float getEdgeFillerRight() {
		return edgeFillerRight;
	}

	public void setEdgeFillerRight(float edgeFillerRight) {
		this.edgeFillerRight = edgeFillerRight;
	}

	public float getEdgeFillerTop() {
		return edgeFillerTop;
	}

	public void setEdgeFillerTop(float edgeFillerTop) {
		this.edgeFillerTop = edgeFillerTop;
	}

	public boolean getEdgeRepair() {
		return edgeRepair;
	}

	public void setEdgeRepair(boolean edgeRepair) {
		this.edgeRepair = edgeRepair;
	}

	public int getJobControlMode() {
		return jobControlMode;
	}

	public void setJobControlMode(int jobControlMode) {
		this.jobControlMode = jobControlMode;
	}

	public int getBlankPageSkip() {
		return blankPageSkip;
	}

	public void setBlankPageSkip(int blankPageSkip) {
		this.blankPageSkip = blankPageSkip;
	}

	public int getScanMode() {
		return scanMode;
	}

	public void setScanMode(int scanMode) {
		this.scanMode = scanMode;
	}

	public int getBarcodeMaxSearchPriorities() {
		return barcodeMaxSearchPriorities;
	}

	public void setBarcodeMaxSearchPriorities(int barcodeMaxSearchPriorities) {
		this.barcodeMaxSearchPriorities = barcodeMaxSearchPriorities;
	}

	public boolean getDigitalEndorser() {
		return digitalEndorser;
	}

	public void setDigitalEndorser(boolean digitalEndorser) {
		this.digitalEndorser = digitalEndorser;
	}

	public int getDigitalEndorserCountDirection() {
		return digitalEndorserCountDirection;
	}

	public void setDigitalEndorserCountDirection(int digitalEndorserCountDirection) {
		this.digitalEndorserCountDirection = digitalEndorserCountDirection;
	}

	public long getDigitalEndorserCounter() {
		return digitalEndorserCounter;
	}

	public void setDigitalEndorserCounter(long digitalEndorserCounter) {
		this.digitalEndorserCounter = digitalEndorserCounter;
	}

	public int getDigitalEndorserCountStep() {
		return digitalEndorserCountStep;
	}

	public void setDigitalEndorserCountStep(int digitalEndorserCountStep) {
		this.digitalEndorserCountStep = digitalEndorserCountStep;
	}

	public String getDigitalEndorserString() {
		return digitalEndorserString;
	}

	public void setDigitalEndorserString(String digitalEndorserString) {
		this.digitalEndorserString = digitalEndorserString;
	}

	public float getDigitalEndorserXOffset() {
		return digitalEndorserXOffset;
	}

	public void setDigitalEndorserXOffset(float digitalEndorserXOffset) {
		this.digitalEndorserXOffset = digitalEndorserXOffset;
	}

	public float getDigitalEndorserYOffset() {
		return digitalEndorserYOffset;
	}

	public void setDigitalEndorserYOffset(float digitalEndorserYOffset) {
		this.digitalEndorserYOffset = digitalEndorserYOffset;
	}

	public int getFilterSaturationSensitivity() {
		return filterSaturationSensitivity;
	}

	public void setFilterSaturationSensitivity(int filterSaturationSensitivity) {
		this.filterSaturationSensitivity = filterSaturationSensitivity;
	}

	public boolean getSynchronizationDigitalEndorser() {
		return synchronizationDigitalEndorser;
	}

	public void setSynchronizationDigitalEndorser(boolean synchronizationDigitalEndorser) {
		this.synchronizationDigitalEndorser = synchronizationDigitalEndorser;
	}

	public boolean getVerticalLineReduction() {
		return verticalLineReduction;
	}

	public void setVerticalLineReduction(boolean verticalLineReduction) {
		this.verticalLineReduction = verticalLineReduction;
	}

	public boolean getAIQCNotice() {
		return aIQCNotice;
	}

	public void setAIQCNotice(boolean aIQCNotice) {
		this.aIQCNotice = aIQCNotice;
	}

	public int getBackgroundSmoothness() {
		return backgroundSmoothness;
	}

	public void setBackgroundSmoothness(int backgroundSmoothness) {
		this.backgroundSmoothness = backgroundSmoothness;
	}

	public int getCropPriority() {
		return cropPriority;
	}

	public void setCropPriority(int cropPriority) {
		this.cropPriority = cropPriority;
	}

	public int getDeskew() {
		return deskew;
	}

	public void setDeskew(int deskew) {
		this.deskew = deskew;
	}

	public float getCropMarginSize() {
		return cropMarginSize;
	}

	public void setCropMarginSize(float cropMarginSize) {
		this.cropMarginSize = cropMarginSize;
	}

	public float getMultiFeedModeChangeSize() {
		return multiFeedModeChangeSize;
	}

	public void setMultiFeedModeChangeSize(float multiFeedModeChangeSize) {
		this.multiFeedModeChangeSize = multiFeedModeChangeSize;
	}	

	public int getBlankPageNotice() {
		return blankPageNotice;
	}

	public void setBlankPageNotice(int blankPageNotice) {
		this.blankPageNotice = blankPageNotice;
	}

	public boolean getHwCompression() {
		return hwCompression;
	}

	public void setHwCompression(boolean hwCompression) {
		this.hwCompression = hwCompression;
	}

	public boolean getScanContinue() {
		return scanContinue;
	}

	public void setScanContinue(boolean scanContinue) {
		this.scanContinue = scanContinue;
	}
	
	public int getAutomaticColorSensitivity() {
		return automaticColorSensitivity;
	}

	public void setAutomaticColorSensitivity(int automaticColorSensitivity) {
		this.automaticColorSensitivity = automaticColorSensitivity;
	}

	public int getDeskewBackground() {
		return deskewBackground;
	}

	public void setDeskewBackground(int deskewBackground) {
		this.deskewBackground = deskewBackground;
	}

	public int getDigitalEndorserDirection() {
		return digitalEndorserDirection;
	}

	public void setDigitalEndorserDirection(int digitalEndorserDirection) {
		this.digitalEndorserDirection = digitalEndorserDirection;
	}

	public int getLengthDetection() {
		return lengthDetection;
	}

	public void setLengthDetection(int lengthDetection) {
		this.lengthDetection = lengthDetection;
	}

	public boolean getMultiFeedNotice() {
		return multiFeedNotice;
	}

	public void setMultiFeedNotice(boolean multiFeedNotice) {
		this.multiFeedNotice = multiFeedNotice;
	}

	public int getBlankPageSkipMode() {
		return blankPageSkipMode;
	}

	public void setBlankPageSkipMode(int blankPageSkipMode) {
		this.blankPageSkipMode = blankPageSkipMode;
	}

}
