/**
 * @(#)FiscnSampleApp.java
 * Copyright PFU LIMITED 2009-2014
 * 
 */
package com.fujitsu.pfu.fiscn.sdksample;

import java.io.File;
import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.w3c.dom.Document;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

import com.fujitsu.pfu.fiscn.sdk.Fiscn;
import com.fujitsu.pfu.fiscn.sdk.FiscnException;

/**
 * Fiscn Sample<BR>
 * <BR>
 */
public class FiscnSampleApp extends Fiscn {

    /**
     * Variable type:int<BR>
     */
    private static final int TYPE_INT = 0;
    /**
     * Variable type:long<BR>
     */
    private static final int TYPE_LONG = 1;
    /**
     * Variable type:float<BR>
     */
    private static final int TYPE_FLOAT = 2;
    /**
     * Variable type:boolean<BR>
     */
    private static final int TYPE_BOOLEAN = 3;
    /**
     * Variable type:String<BR>
     */
    private static final int TYPE_STRING = 4;

    
    /**
     * Constructor<BR>
     */
    public FiscnSampleApp() throws FiscnException {
    }

    /**
     * Event: Issued when a special document (document of a particular form)/Patch Code paper is detected.<BR>
     * To use the event, overwrite the following method.<BR>
     * If not using the event, you do not need to overwrite it.<BR>
     * <BR>
     */
    public void eventDetectJobSeparator() {
        System.out.println("A special document/Patch Code paper document has been detected.");
    }
    
    /**
     * Event: Issued when barcode is detected.<BR>
     * <BR>
     * @param readCount		Scanning image count
     * @param barcodeType	Type of barcode
     * @param barcodeText	Text of barcode
     */
    public void eventDetectBarcode(long readCount, long barcodeType, String barcodeText) {
        System.err.println("Barcode has been detected. \"Scanning image count:" + readCount + "\"  \"Type of Barcode:" + barcodeType + "\"  \"Text of Barcode:" + barcodeText + "\"");
    }
    
    /**
     * Event: Issued when Patch Code is detected.<BR>
     * <BR>
     * @param readCount		Scanning image count
     * @param patchCode		Type of Patch Code
     */
    public void eventDetectPatchCode(long readCount, long patchCode) {
        System.err.println("Patch Code has been detected. \"Scanning image count:" + readCount + "\"  \"Type of Patch Code:" + patchCode + "\"");
    }
    
    /**
     *  Event: Issued when barcode detail is detected.<BR>
     * <BR>
     * @param readCount			Scanning image count
     * @param barcodeCount  	Count of barcode
     * @param barcodeTotalCount Total count of barcode
     * @param barcodeType		Type of barcode
     * @param barcodeTextLength Text length of barcode
     * @param barcodeText		Text of barcode
     * @param barcodeX			Coordinate X of barcode
     * @param barcodeY			Coordinate Y of barcode
     * @param barcodeRotation	Rotation of barcode
     * @param barcodeConfidence -
     */
	public void eventDetectBarcodeDetail(long readCount, long barcodeCount, long barcodeTotalCount, long barcodeType, long barcodeTextLength, String barcodeText, long barcodeX, long barcodeY, long barcodeRotation, long barcodeConfidence) {
        System.err.println("Barcode deteil has been detected. \"Scanning image count:" + readCount + "\"  \"Count:" + barcodeCount + "\"  \"Total count:" + barcodeTotalCount + "\"  \"Type:" + barcodeType + "\"  \"Text length:" + barcodeTextLength + "\"  \"Text:" + barcodeText + "\"  \"X:" + barcodeX + "\"  \"Y:" + barcodeY + "\"  \"Rotation:" + barcodeRotation + "\"");
	}

    /**
     * Event: This event is issued for each page during the scanning process (the StartScan method) when the ScanTo property is set to "0 - File". <BR>
     * <BR>
     * @param readCount		Scanning image count
     * @param fileName		Scanning file name
     */
    public void eventScanToFile(long readCount, String fileName) {
        System.err.println("The scan to file was detected. Scanning image count:" + readCount + " Scanning file name:" + fileName);

        try {
			if (this.getAIQCResult()) {
			    System.err.println("A bad image was detected. Scanning image count:" + readCount);
			} else {
				System.err.println("A bad image was not detected. Scanning image count:" + readCount);
			}
			if (this.getMultiFeedResult()) {
			    System.err.println("A multi feed was detected. Scanning image count:" + readCount);
			} else {
				System.err.println("A multi feed was not detected. Scanning image count:" + readCount);
			}
			if (this.getBlankPageResult() == 1) {
			    System.err.println("A blank page image was detected. Scanning image count:" + readCount);
			} else {
				System.err.println("A blank page image was not detected. Scanning image count:" + readCount);
			}
			System.err.println("The number of pages present in reading:" + this.getPageNumber());
		} catch (FiscnException e) {
			System.err.println("An error has occurred. Error code:" + e.getErrorCode());
		}
    }

    /**
     * Event: Issued when a Page Partition is detected.<BR>
     * To use the event, overwrite the following method.<BR>
     * If not using the event, you do not need to overwrite it.<BR>
     * <BR>
     */
    public void eventPagePartition() {
        System.out.println("Page Partition has been detected.");
    }
 
    /**
     * Event: Configure the TWAIN capability which cannot be configured by this control.
     * To use the event, overwrite the following method.<BR>
     * If not using the event, you do not need to overwrite it.<BR>
     * <BR>
     */
    public void eventNegotiateCapabilities() {
        System.out.println("Configure the TWAIN capability.");
    }
    
    /**
     * Get the DOM document instance from the XML file.<BR>
     * <BR>
     * @param strXmlFilePath Full path of the XML file
     * @return DOM document<BR>
     *          If there are no errors (e.g., no file/unsuccessful file reading), null is returned.
     */
    private Document getXmlDocument(String strXmlFilePath) {
        
        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        DocumentBuilder builder = null;
        Document document = null;
        File file = null;
        
        /*
         * There is no file.
         */
        file = new File(strXmlFilePath);
        if (!file.exists()) {
            return null;
        }
        
        try {
            /*
             * Get the instance of javax.xml.parsers
             * Throw ParserConfigurationException
             */
            builder = factory.newDocumentBuilder();
            
            /*
             * Get the DOM document of the XML file.
             * Throw SAXException and IOException
             */
            document = builder.parse(file);        
            
        } catch (ParserConfigurationException e) {
            e.printStackTrace();
            return null;
        } catch (SAXException e) {
            e.printStackTrace();
            return null;
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        }
        
        return document;
    }
    
    /**
     * Get the content of the XML element.<BR>
     * <BR>
     * @param  document  DOM document instance
     * @param  tagName   Element name
     *
     * @return Element value
     *          If there is no element, null is returned.
     */
    private String getXmlElementContent(Document document, String tagName) {
        //Get the list of elements with a tag name.
        NodeList element = document.getElementsByTagName(tagName);
        if (element != null && element.getLength() > 0) {
            //Get the first element.
            if (element.item(0) != null) {
                String value = element.item(0).getTextContent();
                return value;
            } else {
                //If there is no element, null is returned.
                return null;
            }
        } else {
            //There is no element.
            return null;
        }
    }
    
    /**
     * @param value    Element value
     * @param type     Variable type
     * @return true    Analysis was successful.
     *         false   Analysis failed.
     */
    private  boolean isValidValue(String value, int type) {
    	
    	if (value == null || value.length() == 0) {
    		return false;
    	}
    	
    	try {
            switch (type) {
            case TYPE_INT:
                Integer.parseInt(value);
                break;
            case TYPE_LONG:
                Long.parseLong(value);
                break;
            case TYPE_FLOAT:
                Float.parseFloat(value);
                break;
            case TYPE_BOOLEAN:
                Boolean.parseBoolean(value);
                break;
            case TYPE_STRING:
            	break;
            default:
                //No action required.
                return false;
            }
        } catch (NumberFormatException e) {
            //If analysis fails, false is returned.
            return false;
        }
        
        return true;
	}
    
    /**
     * Save the property.<BR>
     * Get the content of the XML file.<BR>
     * <BR>
     * @param strXmlFilePath    Path of the XML file
     * @return FiscnProperties  Data class
     */
    private FiscnProperties getFiscnProperties(String strXmlFilePath) {
        
        FiscnProperties fps = null;
        String textContent = null;
        Document document = null;
        
        /*
         * Data class variable
         */
        fps = new FiscnProperties();
        
        /*
         * Get the DOM document.
         */
        document = getXmlDocument(strXmlFilePath);
        if (document == null) {
            //There is no file, or file reading failed.
            return null;
        }
        
        textContent = getXmlElementContent(document, "AutoBorderDetection");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setAutoBorderDetection(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "AutoSeparation");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setAutoSeparation(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Background");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBackground(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "BackgroundColor");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBackgroundColor(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Binding");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBinding(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Brightness");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBrightness(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "CloseSourceUI");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setCloseSourceUI(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "CompressionType");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setCompressionType(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Contrast");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setContrast(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "CustomGamma");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setCustomGamma(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "CustomPaperLength");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setCustomPaperLength(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "CustomPaperWidth");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setCustomPaperWidth(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "CustomResolution");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setCustomResolution(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Endorser");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setEndorser(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "EndorserCountDirection");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setEndorserCountDirection(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "EndorserCounter");
        if (isValidValue(textContent,TYPE_LONG)) {
            fps.setEndorserCounter(Long.parseLong(textContent));
        }

        textContent = getXmlElementContent(document, "EndorserCountStep");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setEndorserCountStep(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "EndorserDirection");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setEndorserDirection(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "EndorserOffset");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setEndorserOffset(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "EndorserString");
        if (isValidValue(textContent,TYPE_STRING)) {
            fps.setEndorserString(textContent);
        }

        textContent = getXmlElementContent(document, "FileCounter");
        if (isValidValue(textContent,TYPE_LONG)) {
            fps.setFileCounter(Long.parseLong(textContent));
        }

        textContent = getXmlElementContent(document, "FileName");
        if (isValidValue(textContent,TYPE_STRING)) {
            fps.setFileName(textContent);
        }

        textContent = getXmlElementContent(document, "FileType");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setFileType(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Filter");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setFilter(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Gamma");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setGamma(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "GammaFile");
        if (isValidValue(textContent,TYPE_STRING)) {

            fps.setGammaFile(textContent);
        }

        textContent = getXmlElementContent(document, "Halftone");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setHalftone(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "HalftoneFile");
        if (isValidValue(textContent,TYPE_STRING)) {
            fps.setHalftoneFile(textContent);
        }

        textContent = getXmlElementContent(document, "Highlight");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setHighlight(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Indicator");
        if (isValidValue(textContent,TYPE_BOOLEAN)){
            fps.setIndicator(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "JobControl");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setJobControl(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "JpegQuality");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setJpegQuality(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "LongPage");
        if (isValidValue(textContent,TYPE_BOOLEAN)){
            fps.setLongPage(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "Mirroring");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setMirroring(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "MultiFeed");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setMultiFeed(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "NoiseRemoval");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setNoiseRemoval(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Orientation");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setOrientation(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Outline");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setOutline(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "OverScan");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setOverScan(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Overwrite");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setOverwrite(Integer.parseInt(textContent));
        }    

        textContent = getXmlElementContent(document, "PaperSize");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setPaperSize(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "PaperSupply");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setPaperSupply(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "PixelType");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setPixelType(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "PreFiltering");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setPreFiltering(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "RegionLeft");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setRegionLeft(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "RegionLength");
        if(isValidValue(textContent,TYPE_FLOAT)) {
            fps.setRegionLength(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "RegionTop");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setRegionTop(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "RegionWidth");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setRegionWidth(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "Report");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setReport(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "ReportFile");
        if (isValidValue(textContent,TYPE_STRING)) {
            fps.setReportFile(textContent);
        }

        textContent = getXmlElementContent(document, "Resolution");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setResolution(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Reverse");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setReverse(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "Rotation");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setRotation(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "ScanCount");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setScanCount(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "ScanTo");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setScanTo(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "SEE");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setSEE(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Shadow");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setShadow(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "ShowSourceUI");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setShowSourceUI(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "SilentMode");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setSilentMode(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "SkipBlackPage");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setSkipBlackPage(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "SkipWhitePage");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setSkipWhitePage(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Smoothing");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setSmoothing(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "SourceCurrentScan");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setSourceCurrentScan(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "Threshold");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setThreshold(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "ThresholdCurve");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setThresholdCurve(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "TwainDS");
        if (isValidValue(textContent,TYPE_STRING)) {
            fps.setTwainDS(textContent);
        }

        textContent = getXmlElementContent(document, "UndefinedScanning");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setUndefinedScanning(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "Unit");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setUnit(Integer.parseInt(textContent));
        }
        
        textContent = getXmlElementContent(document, "DTCSensitivity");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setDTCSensitivity(Integer.parseInt(textContent));
        }
        
        textContent = getXmlElementContent(document, "CharacterThickness");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setCharacterThickness(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "FadingCompensation");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setFadingCompensation(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "NoiseRejection");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setNoiseRejection(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "PatternRemoval");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setPatternRemoval(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "PunchHoleRemoval");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setPunchHoleRemoval(Integer.parseInt(textContent));
        }
        
        textContent = getXmlElementContent(document, "Sharpness");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setSharpness(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "AutoBright");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setAutoBright(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "BackgroundSmoothing");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBackgroundSmoothing(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "AutomaticSenseMedium");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setAutomaticSenseMedium(Boolean.parseBoolean(textContent));
        }
        
        textContent = getXmlElementContent(document, "BackgroundThreshold");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBackgroundThreshold(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "SDTCSensitivity");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setSDTCSensitivity(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "ADTCThreshold");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setADTCThreshold(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "sRGB");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setSRGB(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "EndorserFont");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setEndorserFont(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "BarcodeDetection");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setBarcodeDetection(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "BarcodeDirection");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBarcodeDirection(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "BarcodeRegionLeft");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setBarcodeRegionLeft(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "BarcodeRegionLength");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setBarcodeRegionLength(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "BarcodeRegionTop");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setBarcodeRegionTop(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "BarcodeRegionWidth");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setBarcodeRegionWidth(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "BarcodeType");
        if (isValidValue(textContent,TYPE_LONG)) {
            fps.setBarcodeType(Long.parseLong(textContent));
        }

        textContent = getXmlElementContent(document, "PatchCodeDetection");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setPatchCodeDetection(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "PatchCodeDirection");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setPatchCodeDirection(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "PatchCodeType");
        if (isValidValue(textContent,TYPE_LONG)) {
            fps.setPatchCodeType(Long.parseLong(textContent));
        }

        textContent = getXmlElementContent(document, "EdgeFiller");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setEdgeFiller(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "EdgeFillerBottom");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setEdgeFillerBottom(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "EdgeFillerLeft");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setEdgeFillerLeft(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "EdgeFillerRight");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setEdgeFillerRight(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "EdgeFillerTop");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setEdgeFillerTop(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "EdgeRepair");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setEdgeRepair(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "JobControlMode");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setJobControlMode(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "BlankPageSkip");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBlankPageSkip(Integer.parseInt(textContent));
        }
    
        textContent = getXmlElementContent(document, "ScanMode");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setScanMode(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "BarcodeMaxSearchPriorities");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBarcodeMaxSearchPriorities(Integer.parseInt(textContent));
        }
        
        textContent = getXmlElementContent(document, "DigitalEndorser");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setDigitalEndorser(Boolean.parseBoolean(textContent));
        }
        
        textContent = getXmlElementContent(document, "DigitalEndorserCountDirection");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setDigitalEndorserCountDirection(Integer.parseInt(textContent));
        }
        
        textContent = getXmlElementContent(document, "DigitalEndorserCounter");
        if (isValidValue(textContent,TYPE_LONG)) {
            fps.setDigitalEndorserCounter(Long.parseLong(textContent));
        }
        
        textContent = getXmlElementContent(document, "DigitalEndorserCountStep");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setDigitalEndorserCountStep(Integer.parseInt(textContent));
        }
        
        textContent = getXmlElementContent(document, "DigitalEndorserString");
        if (isValidValue(textContent,TYPE_STRING)) {
            fps.setDigitalEndorserString(textContent);
        }
        
        textContent = getXmlElementContent(document, "DigitalEndorserXOffset");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setDigitalEndorserXOffset(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "DigitalEndorserYOffset");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setDigitalEndorserYOffset(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "FilterSaturationSensitivity");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setFilterSaturationSensitivity(Integer.parseInt(textContent));
        }
        
        textContent = getXmlElementContent(document, "SynchronizationDigitalEndorser");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setSynchronizationDigitalEndorser(Boolean.parseBoolean(textContent));
        }
        
        textContent = getXmlElementContent(document, "VerticalLineReduction");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setVerticalLineReduction(Boolean.parseBoolean(textContent));
        }
        
        textContent = getXmlElementContent(document, "AIQCNotice");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setAIQCNotice(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "BackgroundSmoothness");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBackgroundSmoothness(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "CropPriority");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setCropPriority(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "Deskew");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setDeskew(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "CropMarginSize");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setCropMarginSize(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "MultiFeedModeChangeSize");
        if (isValidValue(textContent,TYPE_FLOAT)) {
            fps.setMultiFeedModeChangeSize(Float.parseFloat(textContent));
        }

        textContent = getXmlElementContent(document, "BlankPageNotice");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBlankPageNotice(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "HwCompression");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setHwCompression(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "ScanContinue");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setScanContinue(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "AutomaticColorSensitivity");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setAutomaticColorSensitivity(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "DeskewBackground");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setDeskewBackground(Integer.parseInt(textContent));
        }
        
        textContent = getXmlElementContent(document, "DigitalEndorserDirection");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setDigitalEndorserDirection(Integer.parseInt(textContent));
        }
        
        textContent = getXmlElementContent(document, "LengthDetection");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setLengthDetection(Integer.parseInt(textContent));
        }

        textContent = getXmlElementContent(document, "MultiFeedNotice");
        if (isValidValue(textContent,TYPE_BOOLEAN)) {
            fps.setMultiFeedNotice(Boolean.parseBoolean(textContent));
        }

        textContent = getXmlElementContent(document, "BlankPageSkipMode");
        if (isValidValue(textContent,TYPE_INT)) {
            fps.setBlankPageSkipMode(Integer.parseInt(textContent));
        }

        return fps;
    }
    
    /**
     * Use the setting contents in the XML file for the SDK.<BR>
     * <BR>
     * @param fps Setting contents in the XML file
     * @throws FiscnException Other SDK settings
     */
    private void setFiscnProperties(FiscnProperties fps) throws FiscnException {
  	
    	//-------------------------------------------------------------------
        // Scan related properties
        //-------------------------------------------------------------------
    	
        this.setOutline(0);

        this.setScanTo(fps.getScanTo());
        
        this.setScanContinue(fps.getScanContinue());

        this.setFileType(fps.getFileType());

        this.setFileName(fps.getFileName());

        this.setOverwrite(fps.getOverwrite());

        this.setFileCounter(fps.getFileCounter());

        this.setCompressionType(fps.getCompressionType());

        this.setJpegQuality(fps.getJpegQuality());

        this.setPaperSupply(fps.getPaperSupply());

        this.setScanCount(fps.getScanCount());

        this.setPaperSize(fps.getPaperSize());

        this.setOrientation(fps.getOrientation());

        this.setLongPage(fps.getLongPage());

        this.setUndefinedScanning(fps.getUndefinedScanning());  

        this.setBackgroundColor(fps.getBackgroundColor());

        this.setCustomPaperWidth(fps.getCustomPaperWidth());

        this.setCustomPaperLength(fps.getCustomPaperLength());

        this.setRegionLeft(fps.getRegionLeft());

        this.setRegionTop(fps.getRegionTop());

        this.setRegionWidth(fps.getRegionWidth());

        this.setRegionLength(fps.getRegionLength());

        this.setPixelType(fps.getPixelType());
        
        this.setAutomaticColorSensitivity(fps.getAutomaticColorSensitivity());
        
        this.setResolution(fps.getResolution());

        this.setCustomResolution(fps.getCustomResolution());

        this.setBrightness(fps.getBrightness());

        this.setContrast(fps.getContrast());

        this.setThreshold(fps.getThreshold());

        this.setReverse(fps.getReverse());

        this.setMirroring(fps.getMirroring());

        this.setRotation(fps.getRotation());

        this.setBackground(fps.getBackground());

        this.setOutline(fps.getOutline());

        this.setAutoSeparation(fps.getAutoSeparation());

        this.setSEE(fps.getSEE());

        this.setHalftone(fps.getHalftone());

        this.setHalftoneFile(fps.getHalftoneFile());

        this.setGamma(fps.getGamma());

        this.setGammaFile(fps.getGammaFile());

        this.setCustomGamma(fps.getCustomGamma());
        
        this.setDTCSensitivity(fps.getDTCSensitivity());
        
        this.setCharacterThickness(fps.getCharacterThickness());
        
        this.setFadingCompensation(fps.getFadingCompensation());
        
        this.setNoiseRejection(fps.getNoiseRejection());
        
        this.setPatternRemoval(fps.getPatternRemoval());
        
        this.setPunchHoleRemoval(fps.getPunchHoleRemoval());
        
        this.setSharpness(fps.getSharpness());
        
        this.setAutoBright(fps.getAutoBright());
        
        this.setBackgroundSmoothing(fps.getBackgroundSmoothing());
        
        this.setAutomaticSenseMedium(fps.getAutomaticSenseMedium());
        
        this.setBackgroundThreshold(fps.getBackgroundThreshold());
        
        this.setSDTCSensitivity(fps.getSDTCSensitivity());
        
        this.setADTCThreshold(fps.getADTCThreshold());
        
        this.setsRGB(fps.getSRGB());
        
        this.setScanMode(fps.getScanMode());
        
        this.setVerticalLineReduction(fps.getVerticalLineReduction());
        
        this.setBackgroundSmoothness(fps.getBackgroundSmoothness());

        //---------------------------------------------------------
        // Operation related properties
        //---------------------------------------------------------

        this.setShowSourceUI(fps.getShowSourceUI());

        this.setCloseSourceUI(fps.getCloseSourceUI());

        this.setSourceCurrentScan(fps.getSourceCurrentScan());

        this.setSilentMode(fps.getSilentMode());

        this.setReport(fps.getReport());

        this.setReportFile(fps.getReportFile());

       
        //------------------------------------------------------------
        // Automatic binarization related properties
        //------------------------------------------------------------

        this.setThresholdCurve(fps.getThresholdCurve());

        this.setNoiseRemoval(fps.getNoiseRemoval());

        this.setPreFiltering(fps.getPreFiltering());

        this.setSmoothing(fps.getSmoothing());
        
        //-------------------------------------------------------------
        // Endorser related properties
        //-------------------------------------------------------------

        this.setEndorser(fps.getEndorser());

        this.setEndorserString(fps.getEndorserString());

        this.setEndorserCounter(fps.getEndorserCounter());

        this.setEndorserOffset(fps.getEndorserOffset());
 
        this.setEndorserDirection(fps.getEndorserDirection());

        this.setEndorserCountStep(fps.getEndorserCountStep());

        this.setEndorserCountDirection(fps.getEndorserCountDirection());
 
        this.setEndorserFont(fps.getEndorserFont());
        
        this.setSynchronizationDigitalEndorser(fps.getSynchronizationDigitalEndorser());

        this.setDigitalEndorser(fps.getDigitalEndorser());

        this.setDigitalEndorserString(fps.getDigitalEndorserString());

        this.setDigitalEndorserCounter(fps.getDigitalEndorserCounter());

        this.setDigitalEndorserCountStep(fps.getDigitalEndorserCountStep());

        this.setDigitalEndorserCountDirection(fps.getDigitalEndorserCountDirection());
        
        this.setDigitalEndorserDirection(fps.getDigitalEndorserDirection());
        
        this.setDigitalEndorserXOffset(fps.getDigitalEndorserXOffset());
        
        this.setDigitalEndorserYOffset(fps.getDigitalEndorserYOffset());
        
        //-------------------------------------------------------------
        // Special function related properties
        //-------------------------------------------------------------

        this.setJobControl(fps.getJobControl());
        
        this.setJobControlMode(fps.getJobControlMode());

        this.setBinding(fps.getBinding());

        this.setMultiFeed(fps.getMultiFeed());

        this.setFilter(fps.getFilter());

        this.setFilterSaturationSensitivity(fps.getFilterSaturationSensitivity());
        
        this.setSkipWhitePage(fps.getSkipWhitePage());

        this.setSkipBlackPage(fps.getSkipBlackPage());
        
        this.setBlankPageSkip(fps.getBlankPageSkip());

        this.setBlankPageNotice(fps.getBlankPageNotice());
        
        this.setBlankPageSkipMode(fps.getBlankPageSkipMode());

        this.setAutoBorderDetection(fps.getAutoBorderDetection());

        this.setTwainDS(fps.getTwainDS());

        this.setIndicator(fps.getIndicator());

        this.setHighlight(fps.getHighlight());

        this.setShadow(fps.getShadow());

        this.setOverScan(fps.getOverScan());

        this.setUnit(fps.getUnit());

        this.setAIQCNotice(fps.getAIQCNotice());
        
        this.setMultiFeedNotice(fps.getMultiFeedNotice());

        this.setCropPriority(fps.getCropPriority());

        this.setDeskew(fps.getDeskew());
        
        this.setDeskewBackground(fps.getDeskewBackground()); 
        
        this.setCropMarginSize(fps.getCropMarginSize());
        
        this.setMultiFeedModeChangeSize(fps.getMultiFeedModeChangeSize());

        this.setHwCompression(fps.getHwCompression());
        
        this.setLengthDetection(fps.getLengthDetection());

        //-------------------------------------------------------------
        // Barcode function related properties
        //-------------------------------------------------------------

        this.setBarcodeDetection(fps.getBarcodeDetection());
        
        this.setBarcodeDirection(fps.getBarcodeDirection());
        
        this.setBarcodeMaxSearchPriorities(fps.getBarcodeMaxSearchPriorities());
        
        this.setBarcodeRegionLeft(fps.getBarcodeRegionLeft());
        
        this.setBarcodeRegionLength(fps.getBarcodeRegionLength());
        
    	this.setBarcodeRegionTop(fps.getBarcodeRegionTop());
    	
    	this.setBarcodeRegionWidth(fps.getBarcodeRegionWidth());
    	
    	this.setBarcodeType(fps.getBarcodeType());
    	
        //-------------------------------------------------------------
        // Patch Code function related properties
        //-------------------------------------------------------------

    	this.setPatchCodeDetection(fps.getPatchCodeDetection());
    	
    	this.setPatchCodeDirection(fps.getPatchCodeDirection());
    	
    	this.setPatchCodeType(fps.getPatchCodeType());
    	
        //-------------------------------------------------------------
        // Edge Filler function related properties
        //-------------------------------------------------------------

    	this.setEdgeFiller(fps.getEdgeFiller());
    	
    	this.setEdgeFillerBottom(fps.getEdgeFillerBottom());
    	
    	this.setEdgeFillerLeft(fps.getEdgeFillerLeft());
    	
    	this.setEdgeFillerRight(fps.getEdgeFillerRight());
    	
    	this.setEdgeFillerTop(fps.getEdgeFillerTop());
    	
    	this.setEdgeRepair(fps.getEdgeRepair());

    }

    /**
     * main Method<BR>
     */
    public static void main(String[] args) throws FiscnException {

        FiscnSampleApp app = null; 
        
        /*
         * Data class variable
         */
        FiscnProperties fps = new FiscnProperties();
        /*
         * Recognize the first parameter as the XML file.
         */
        String strXmlFilePath = null;
        if (args != null && args.length > 0) {
            if (args[0] != null && args[0].length() > 0) {
                strXmlFilePath = args[0];
            }
        }
        
        try {
            
            app = new FiscnSampleApp();
            /*
             * Call the initialize() method before opening the scanner.
             */
            app.initialize(app);
            System.out.println("The scanner has been initialized.");

            /*
             * Open the scanner.
             */
    		app.selectSourceName("PaperStream IP fi-6130Zdj");
            
            app.openScanner();
            System.out.println("The scanner has been opened.");
            
            /*
             * Construct the data class after analyzing the XML file.
             */
            if (strXmlFilePath != null) {
                fps = app.getFiscnProperties(strXmlFilePath);
                if (fps != null) {

                    app.setFiscnProperties(fps);
                    System.out.println("Properties have been specified for the scanner.");
                } else {
                    System.out.println("Failed to read the XML file."
                            + "Use default properties.");
                }
            } else {
                System.out.println("An XML file has not been specified."
                        + "Use default properties.");
            }
            
            /*
             * Start scanning.
             */ 
            app.startScan();
            System.out.println("Scanning has started.");
            
            /*
             * Close the scanner.
             */
            app.closeScanner();
            System.out.println("The scanner has been closed.");
            
        } catch(FiscnException ex){
            System.err.println("An error has occurred. Error code:" + ex.getErrorCode());
        } finally {
            if (app != null) {
                /*
                 * Make sure to call the unInitialize() method, 
                 * as the initialize() method has been called.
                 */
                app.unInitialize();
                System.out.println("The scan has completed.");
            }
        }
    }
}
